﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.Mvc;
using System.Web.Routing;

namespace SGA
{
    public class RouteConfig
    {
        public static void RegisterRoutes(RouteCollection routes)
        {
            routes.IgnoreRoute("{resource}.axd/{*pathInfo}");

            //RUTAS DE USUARIO
            routes.MapRoute(
                name: "UserCrud",
                url: "User/crud/{user}",
                defaults: new { controller = "User", action = "Crud", user = UrlParameter.Optional }
            );

            routes.MapRoute(
                name: "UserGuardar",
                url: "User/guardar/{user}",
                defaults: new { controller = "User", action = "Guardar", user = UrlParameter.Optional }
            );

            routes.MapRoute(
                name: "UserEliminar",
                url: "User/eliminar/{user}",
                defaults: new { controller = "User", action = "Eliminar", user = UrlParameter.Optional }
                );

            routes.MapRoute(
                name: "UserVer",
                url: "User/ver/{user}",
                defaults: new { controller = "User", action = "Ver", user = UrlParameter.Optional }
            );

            routes.MapRoute(
                name: "UserIndex",
                url: "User/{action}",
                defaults: new { controller = "User", action = "Index" }
            );
            //===============================================

            //RUTAS DE FORMATOS DE ARTICULOS

            routes.MapRoute(
                name: "FormatosCrud",
                url: "Formatos/crud/{codigo}/{nFormato}",
                defaults: new { controller = "Formatos", action = "Crud", codigo = UrlParameter.Optional, nFormato = UrlParameter.Optional }
            );

            //Se utiliza para crear formatos nuevos asociados a un artículo, por tanto sólo hay que pasar el código de artículo
            routes.MapRoute(
                name: "FormatosCrud2",
                url: "Formatos/crud/{codigo}",
                defaults: new { controller = "Formatos", action = "Crud", codigo = UrlParameter.Optional }
            );

            routes.MapRoute(
                name: "FormatosGuardar",
                url: "Formatos/guardar/{codigo}",
                defaults: new { controller = "Formatos", action = "Guardar", codigo = UrlParameter.Optional }
            );

            routes.MapRoute(
                name: "Formatos/Eliminar",
                url: "Formatos/eliminar/{codigo}/{nFormato}",
                defaults: new { controller = "Formatos", action = "Eliminar", codigo = UrlParameter.Optional, nFormato = UrlParameter.Optional }
            );

            routes.MapRoute(
                name: "FormatosVer",
                url: "Formatos/ver/{codigo}/{nFormato}",
                defaults: new { controller = "Formatos", action = "Ver", codigo = UrlParameter.Optional, nFormato = UrlParameter.Optional }
            );

            //=======================

            //RUTAS DE ARTICULOS

            routes.MapRoute(
                name: "ArticulosCrud",
                url: "Articulos/crud/{codigo}",
                defaults: new { controller = "Articulos", action = "Crud" , codigo = UrlParameter.Optional }
            );

            routes.MapRoute(
                name: "ArticulosGuardar",
                url: "Articulos/guardar/{codigo}",
                defaults: new { controller = "Articulos", action = "Guardar",  codigo = UrlParameter.Optional }
            );

            routes.MapRoute(
                name: "ArticulosEliminar",
                url: "Articulos/eliminar/{codigo}",
                defaults: new { controller = "Articulos", action = "Eliminar", codigo = UrlParameter.Optional }
            );

            routes.MapRoute(
                name: "ArticulosVer",
                url: "Articulos/ver/{codigo}",
                defaults: new { controller = "Articulos", action = "Ver", codigo = UrlParameter.Optional }
            );

            routes.MapRoute(
                name: "ArticulosIndex",
                url: "Articulos/{action}",
                defaults: new { controller = "Articulos", action = "Index" }
            );

            //===========================

            // RUTAS DE UBICACIONES

            routes.MapRoute(
                name: "UbicacionesIndex",
                url: "Ubicaciones/{action}",
                defaults: new { controller = "Ubicaciones", action = "Index" }
            );

            routes.MapRoute(
                name: "UbicacionesAlmacen",
                url: "Ubicaciones/ZonasPorAlmacen/{almacen}",
                defaults: new { controller = "Ubicaciones", action = "ZonasPorAlmacen", almacen = UrlParameter.Optional }
            );

            routes.MapRoute(
                name: "EstantesPorZona",
                url: "Ubicaciones/EstantesPorZona/{zona}",
                defaults: new { controller = "Ubicaciones", action = "EstantesPorZona", zona = UrlParameter.Optional }
            );

            routes.MapRoute(
                name: "UbicacionesPorEstante",
                url: "Ubicaciones/UbicacionesPorEstante/{estanteria}",
                defaults: new { controller = "Ubicaciones", action = "UbicacionesPorEstante", estanteria = UrlParameter.Optional }
            );

            routes.MapRoute(
                name: "AddAlmacen",
                url: "Ubicaciones/AddAlmacen/{model}",
                defaults: new { controller = "Ubicaciones", action = "AddAlmacen", model = UrlParameter.Optional }
            );

            routes.MapRoute(
                name: "AddZona",
                url: "Ubicaciones/AddZona/{model}",
                defaults: new { controller = "Ubicaciones", action = "AddZona", model = UrlParameter.Optional }
            );

            routes.MapRoute(
                name: "AddUbicaciones",
                url: "Ubicaciones/AddUbicaciones/{model}",
                defaults: new { controller = "Ubicaciones", action = "AddUbicaciones", model = UrlParameter.Optional }
            );

            routes.MapRoute(
                name: "getOrdenacion",
                url: "Ubicaciones/GetOrdenacion/{model}",
                defaults: new { controller = "Ubicaciones", action = "GetOrdenacion", model = UrlParameter.Optional }
            );

            routes.MapRoute(
               name: "GetOpcionesUbicacion",
               url: "Ubicaciones/GetOpcionesUbicacion/{model}",
               defaults: new { controller = "Ubicaciones", action = "GetOpcionesUbicacion", model = UrlParameter.Optional }
           );

            routes.MapRoute(
              name: "GuardarOpcionesUbicacion",
              url: "Ubicaciones/GuardarOpcionesUbicacion/{model}",
              defaults: new { controller = "Ubicaciones", action = "GuardarOpcionesUbicacion", model = UrlParameter.Optional }
          );

            //===========================

            // RUTAS DE ZONAS

            routes.MapRoute(
             name: "ZonasCrud",
             url: "Zonas/Crud/{id}",
             defaults: new { controller = "Zonas", action = "Crud", id = UrlParameter.Optional }
             );

            routes.MapRoute(
                name: "ZonasIndex",
                url: "Zonas/{action}",
                defaults: new { controller = "Zonas", action = "Index" }
            );

            routes.MapRoute(
               name: "ZonasGuardar",
               url: "Zonas/guardar/{zone}",
               defaults: new { controller = "Zonas", action = "Guardar", zone = UrlParameter.Optional }
            );

            routes.MapRoute(
                name: "ZonasEliminar",
                url: "Zonas/eliminar/{codigo}/{tipo}",
                defaults: new { controller = "Zonas", action = "Eliminar", codigo = UrlParameter.Optional, tipo= UrlParameter.Optional }
            );

            //===========================

            // ENTRADAS Y SALIDAS

            routes.MapRoute(
             name: "Entradas",
             url: "ES/Entradas",
             defaults: new { controller = "EntradasSalidas", action = "Entradas"}
             );

            routes.MapRoute(
                name: "Salidas",
                url: "ES/Salidas",
                defaults: new { controller = "EntradasSalidas", action = "Salidas" }
            );

            routes.MapRoute(
               name: "CrudEntrada",
               url: "ES/CrudEntrada/{codigo}",
               defaults: new { controller = "EntradasSalidas", action = "CrudEntrada", codigo = UrlParameter.Optional }
            );

            routes.MapRoute(
               name: "VerEntrada",
               url: "ES/VerEntrada/{codigo}",
               defaults: new { controller = "EntradasSalidas", action = "VerEntrada", codigo = UrlParameter.Optional }
            );

            routes.MapRoute(
              name: "CrudSalida",
              url: "ES/CrudSalida/{codigo}",
              defaults: new { controller = "EntradasSalidas", action = "CrudSalida", codigo = UrlParameter.Optional }
            );

            routes.MapRoute(
              name: "VerSalida",
              url: "ES/VerSalida/{codigo}",
              defaults: new { controller = "EntradasSalidas", action = "VerSalida", codigo = UrlParameter.Optional }
           );

            routes.MapRoute(
               name: "GuardarEntrada",
               url: "ES/GuardarEntrada/{codigo}",
               defaults: new { controller = "EntradasSalidas", action = "GuardarEntrada", codigo = UrlParameter.Optional }
           );

            routes.MapRoute(
              name: "GuardarSalida",
              url: "ES/GuardarSalida/{codigo}",
              defaults: new { controller = "EntradasSalidas", action = "GuardarSalida", codigo = UrlParameter.Optional }
          );

            routes.MapRoute(
              name: "EliminarEntrada",
              url: "ES/EliminarEntrada/{codigo}",
              defaults: new { controller = "EntradasSalidas", action = "EliminarEntrada", codigo = UrlParameter.Optional }
          );

            routes.MapRoute(
              name: "EliminarSalida",
              url: "ES/EliminarSalida/{codigo}",
              defaults: new { controller = "EntradasSalidas", action = "EliminarSalida", codigo = UrlParameter.Optional }
          );

            routes.MapRoute(
              name: "VerLE",
              url: "ES/VerLE/{identrada}/{codigo}",
              defaults: new { controller = "EntradasSalidas", action = "VerLEntrada", identrada= UrlParameter.Optional, codigo = UrlParameter.Optional }
          );

            routes.MapRoute(
              name: "VerLS",
              url: "ES/VerLS/{idsalida}/{codigo}",
              defaults: new { controller = "EntradasSalidas", action = "VerLSalida", idsalida = UrlParameter.Optional, codigo = UrlParameter.Optional }
          );

            routes.MapRoute(
               name: "CrudLE",
               url: "ES/CrudLE/{identrada}/{codigo}",
               defaults: new { controller = "EntradasSalidas", action = "CrudLEntrada", identrada = UrlParameter.Optional, codigo = UrlParameter.Optional }
           );

            routes.MapRoute(
              name: "CrudLE2",
              url: "ES/CrudLE/{identrada}",
              defaults: new { controller = "EntradasSalidas", action = "CrudLEntrada", identrada = UrlParameter.Optional}
          );

            routes.MapRoute(
               name: "CrudLS",
               url: "ES/CrudLS/{idsalida}/{codigo}",
               defaults: new { controller = "EntradasSalidas", action = "CrudLSalida", idsalida = UrlParameter.Optional, codigo = UrlParameter.Optional }
           );

            routes.MapRoute(
              name: "CrudLS2",
              url: "ES/CrudLS/{idsalida}",
              defaults: new { controller = "EntradasSalidas", action = "CrudLSalida", idsalida = UrlParameter.Optional}
          );

            routes.MapRoute(
              name: "GuardarLEntrada",
              url: "ES/GuardarLEntrada/{codigo}",
              defaults: new { controller = "EntradasSalidas", action = "GuardarLEntrada", codigo = UrlParameter.Optional }
          );

            routes.MapRoute(
              name: "GuardarLSalida",
              url: "ES/GuardarLSalida/{codigo}",
              defaults: new { controller = "EntradasSalidas", action = "GuardarLSalida", codigo = UrlParameter.Optional }
          );

            routes.MapRoute(
               name: "EliminarLE",
               url: "ES/EliminarLE/{identrada}/{codigo}",
               defaults: new { controller = "EntradasSalidas", action = "EliminarLEntrada", identrada = UrlParameter.Optional, codigo = UrlParameter.Optional }
           );

            routes.MapRoute(
              name: "EliminarLS",
              url: "ES/EliminarLS/{idsalida}/{codigo}",
              defaults: new { controller = "EntradasSalidas", action = "EliminarLSalida", idsalida = UrlParameter.Optional, codigo = UrlParameter.Optional }
          );

            //================================= TERMINAL =====================

            routes.MapRoute(
              name: "IndexTerminal",
              url: "Home/IndexT",
              defaults: new { controller = "Home", action = "IndexT" }
           );

            routes.MapRoute(
             name: "MenuTerminal",
             url: "Terminal/Menu",
             defaults: new { controller = "Terminales", action = "Index" }
            );

            routes.MapRoute(
             name: "EntradasTerminal",
             url: "Terminal/Entradas",
             defaults: new { controller = "Terminales", action = "Entradas" }
            );

            routes.MapRoute(
            name: "SalidasTerminal",
            url: "Terminal/Salidas",
            defaults: new { controller = "Terminales", action = "Salidas" }
           );

            routes.MapRoute(
            name: "AsignarEntrada",
            url: "Terminal/AsignarE/{id}",
            defaults: new { controller = "Terminales", action = "AsignarENTC", id= UrlParameter.Optional  }
           );

            routes.MapRoute(
            name: "AsignarSalida",
            url: "Terminal/AsignarS/{id}",
            defaults: new { controller = "Terminales", action = "AsignarSALC", id = UrlParameter.Optional }
           );

            routes.MapRoute(
            name: "InventarioTerminal",
            url: "Terminal/Inventario",
            defaults: new { controller = "Terminales", action = "Inventario" }
           );

           routes.MapRoute(
            name: "GuardarInventarioTerminal",
            url: "Terminal/GuardarInventario/{inventario}",
            defaults: new { controller = "Terminales", action = "GuardarInventario", inventario = UrlParameter.Optional }
           );

            routes.MapRoute(
            name: "AddInventarioTerminal",
            url: "Terminal/AddInventario/{codigo}",
            defaults: new { controller = "Terminales", action = "AddInventario", codigo = UrlParameter.Optional }
           );

            routes.MapRoute(
            name: "DelInventarioTerminal",
            url: "Terminal/DelInventario/{codigo}",
            defaults: new { controller = "Terminales", action = "DelInventario", codigo = UrlParameter.Optional }
           );

            routes.MapRoute(
            name: "DetalleInventarioTerminal",
            url: "Terminal/DetalleInventario/{codigo}",
            defaults: new { controller = "Terminales", action = "DetalleInventario", codigo = UrlParameter.Optional }
           );

            routes.MapRoute(
              name: "TerminalVerEntrada",
              url: "Terminal/VerEntrada/{codigo}",
              defaults: new { controller = "Terminales", action = "VerEntrada", codigo = UrlParameter.Optional }
           );

            routes.MapRoute(
             name: "TerminalVerSalida",
             url: "Terminal/VerSalida/{codigo}",
             defaults: new { controller = "Terminales", action = "VerSalida", codigo = UrlParameter.Optional }
          );

            routes.MapRoute(
              name: "TerminalPEntrada",
              url: "Terminal/ProcesarEntrada/{codigo}",
              defaults: new { controller = "Terminales", action = "ProcesarEntrada", codigo = UrlParameter.Optional }
           );

            routes.MapRoute(
             name: "TerminalPSalida",
             url: "Terminal/ProcesarSalida/{codigo}",
             defaults: new { controller = "Terminales", action = "ProcesarSalida", codigo = UrlParameter.Optional }
          );


            //=========================

            routes.MapRoute(
           name: "VerDetalleHistoricoE",
           url: "Home/VerHistoricoE/{codigo}",
           defaults: new { controller = "Home", action = "VerHistoricoE", codigo = UrlParameter.Optional }
          );

            routes.MapRoute(
            name: "VerDetalleHistoricoS",
            url: "Home/VerHistoricoS/{codigo}",
            defaults: new { controller = "Home", action = "VerHistoricoS", codigo = UrlParameter.Optional }
           );

            // RUTA POR DEFECTO

            routes.MapRoute(
               name: "Default",
               url: "{controller}/{action}",
               defaults: new { controller = "Home", action = "Index" }
            );
           

        }
    }
}
