﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.Mvc;
using SGA.Models;
using Insya.Localization;

namespace SGA.Controllers
{
    public class ArticulosController : BaseController
    {
        private ARTC articulo = new ARTC();
        private List<ARTF> formatosArticulo = new List<ARTF>();

        /// <summary>
        /// Principal
        /// </summary>
        /// <returns></returns>
        public ActionResult Index()
        {
            return View(articulo.Listar());
        }

        /// <summary>
        /// Creación o edición de artículos
        /// </summary>
        /// <param name="codigo"></param>
        /// <returns></returns>
        public ActionResult Crud(string codigo = null)
        {
            return View(codigo != null ? articulo.Obtener(codigo) : articulo);
        }

        /// <summary>
        /// Detalle de productos
        /// </summary>
        /// <param name="codigo"></param>
        /// <returns></returns>
        public ActionResult Ver(string codigo)
        {
            return View(articulo.Obtener(codigo));
        }

        /// <summary>
        /// Guardar el articulo recibido por el formulario
        /// </summary>
        /// <param name="article"></param>
        /// <param name="orden"></param>
        /// <returns></returns>
        public ActionResult Guardar(ARTC article, int orden)
        {

            if(ModelState.IsValid)
            {
                switch (orden)
                {
                    case 1:
                        article.bART_FIFO = true;
                        break;
                    case 2:
                        article.bART_LIFO = true;
                        break;
                    case 3:
                        article.bART_LOTE = true;
                        break;
                }
                try
                {
                    article.Guardar();
                    return Redirect("~/articulos/ver/" + article.sARTC_CODIGO);
                }
                catch (Exception)
                {
                    ModelState.AddModelError("", Localization.Localize("excepcionCreacion")); //adicionar mensaje de error al modelo
                    return View("~/Views/articulos/Crud.cshtml", article);
                }
                
            }
            else
            {
                return View("~/Views/articulos/Crud.cshtml", article);
            }    
            
        }

        /// <summary>
        /// Eliminar el articulo indicado
        /// </summary>
        /// <param name="codigo"></param>
        /// <returns></returns>
        public ActionResult Eliminar(string codigo)
        {
            articulo.Eliminar(codigo);
            return Redirect("~/articulos");
        }
    }
}
