﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.Mvc;
using SGA.Models;

namespace SGA.Controllers
{
    public class EntradasSalidasController : BaseController
    {
        private ENTC pEntrada = new ENTC();
        private ENTL lEntrada = new ENTL();
        private SALC pSalida = new SALC();
        private SALL lSalida = new SALL();

        // GET: EntradasSalidas
        public ActionResult Entradas()
        {
            return View(pEntrada.Listar());
        }

        //Muestra el listado de salidas
        public ActionResult Salidas()
        {
            return View(pSalida.Listar());
        }

        //Muestra en detalle una entrada
        public ActionResult VerEntrada(int codigo)
        {
            return View(pEntrada.Obtener(codigo));
        }

        //Crea o edita una entrada
        public ActionResult CrudEntrada(int codigo=0)
        {
            return View(codigo != 0 ? pEntrada.Obtener(codigo) : pEntrada);
        }

        //Muestra en detalle una salida
        public ActionResult VerSalida(int codigo)
        {
            return View(pSalida.Obtener(codigo));
        }

        //Crea o edita una salida
        public ActionResult CrudSalida(int codigo=0)
        {
            return View(codigo != 0 ? pSalida.Obtener(codigo) : pSalida);
        }

        //Guardar los cambios en una entrada
        public ActionResult GuardarEntrada(ENTC entrada)
        {
            if (ModelState.IsValid)
            {
                entrada.Guardar();
                return Redirect("~/es/verentrada/" + entrada.id);
            }
            else
            {
                return View("~/Views/EntradasSalidas/CrudEntrada.cshtml",entrada);
            }
        }

        //Guardar los datos en una salida
        public ActionResult GuardarSalida(SALC salida)
        {
            if (ModelState.IsValid)
            {
                salida.Guardar();
                return Redirect("~/es/versalida/" + salida.id);
            }
            else
            {
                return View("~/Views/EntradasSalidas/CrudSalida.cshtml", salida);
            }
        }

        //Eliminar una entrada
        public ActionResult EliminarEntrada(int codigo)
        {
            pEntrada.Eliminar(codigo);
            return Redirect("~/es/entradas");
        }

        //Eliminar una salida
        public ActionResult EliminarSalida(int codigo)
        {
            pSalida.Eliminar(codigo);
            return Redirect("~/es/salidas");
        }

        //Muestra los articulos asociados a una entrada
        public ActionResult VerLEntrada(int idEntrada = 0, int codigo = 0)
        {
            return View(lEntrada.Obtener(idEntrada, codigo));
        }

        //Asocia articulos a un pedido o edita
        public ActionResult CrudLEntrada(int idEntrada = 0, int codigo = 0)
        {
            lEntrada.sENTL_IDENTRADA = idEntrada;
            return View(codigo != 0 & idEntrada !=0 ? lEntrada.Obtener(idEntrada, codigo) : lEntrada);
        }

        public ActionResult VerLSalida(int idSalida = 0, int codigo = 0)
        {
            return View(lSalida.Obtener(idSalida, codigo));
        }

        public ActionResult CrudLSalida(int idSalida = 0, int codigo = 0)
        {
            lSalida.sSALL_IDSALIDA = idSalida;
            return View(codigo != 0 & idSalida != 0 ? lSalida.Obtener(idSalida, codigo) : lSalida);
        }

        public ActionResult GuardarLEntrada(ENTL lEntrada)
        {
            if (ModelState.IsValid)
            {
                lEntrada.Guardar();
                return Redirect("~/es/verentrada/" + lEntrada.sENTL_IDENTRADA);
            }
            else
            {
                return View("~/Views/EntradasSalidas/CrudLEntrada.cshtml", lEntrada);
            }
        }

        public ActionResult GuardarLSalida(SALL lSalida)
        {
            if (ModelState.IsValid)
            {
                lSalida.Guardar();
                return Redirect("~/es/versalida/" + lSalida.sSALL_IDSALIDA);
            }
            else
            {
                return View("~/Views/EntradasSalidas/CrudLSalida.cshtml", lSalida);
            }
        }

        public ActionResult EliminarLEntrada(int idEntrada = 0, int codigo = 0)
        {
            lEntrada.Eliminar(idEntrada, codigo);
            return Redirect("~/es/verentrada/" + idEntrada);
        }

        public ActionResult EliminarLSalida(int idSalida = 0, int codigo = 0)
        {
            lSalida.Eliminar(idSalida, codigo);
            return Redirect("~/es/versalida/" + idSalida);
        }

    }
}