﻿using Insya.Localization;
using SGA.Models;
using System;
using System.Collections.Generic;
using System.Data.Entity.Validation;
using System.Linq;
using System.Web;
using System.Web.Mvc;

namespace SGA.Controllers
{
    public class TerminalesController : BaseController
    {
        private ENTC entradas= new ENTC();
        private SALC salidas = new SALC();
        private ENTL lEntrada = new ENTL();
        private SALL lSalida = new SALL();
        private UBCI inventario = new UBCI();

        // Menu inicial terminales
        public ActionResult Index()
        {
            return View();
        }

        //Menu de entradas
        public ActionResult Entradas()
        {
            return View(entradas.Listar());
        }

        //Menu de salidas
        public ActionResult Salidas()
        {
            return View(salidas.Listar());
        }

        //Asignar entrada al usuario
        public ActionResult AsignarENTC(int id)
        {
            ENTU entu = new ENTU();
            entu.iENTU_id = id;
            entu.sENTU_USUARIO = Session["LogedUserFullname"].ToString();
            entu.Guardar();
            return RedirectToAction("IndexT", "Home");
        }

        //Asignar salida al usuario
        public ActionResult AsignarSALC(int id)
        {
            SALU salu = new SALU();
            salu.iSALU_id = id;
            salu.sSALU_USUARIO = Session["LogedUserFullname"].ToString();
            salu.Guardar();
            return RedirectToAction("IndexT", "Home");
        }

        //Ver pedido entrada para procesar
        public ActionResult VerEntrada(int codigo)
        {
            ENTC entrada = entradas.Obtener(codigo);
            entrada.dENTC_FINICIO = DateTime.Now;
            entrada.Guardar();
            return View(entrada);
        }

        //Ver pedido salida para procesar
        public ActionResult VerSalida(int codigo)
        {
            SALC salida = salidas.Obtener(codigo);
            salida.dSALC_FINICIO= DateTime.Now;
            salida.Guardar();
            return View(salida);
        }

        //Procesar pedido entrada
        public ActionResult ProcesarEntrada(int codigo)
        {
            ENTC entrada = entradas.Obtener(codigo);
            entrada.dENTC_FFIN = DateTime.Now;
            HENC hEntrada = new HENC();
            hEntrada.bHENC_AUTOMATICO = entrada.bENTC_AUTOMATICO;
            hEntrada.dHENC_FECHA = entrada.dENTC_FECHA;
            hEntrada.dHENC_FFIN = (DateTime)entrada.dENTC_FFIN;
            hEntrada.dHENC_FFINREAL = (DateTime)entrada.dENTC_FFIN;
            hEntrada.dHENC_FINICIO = (DateTime)entrada.dENTC_FINICIO;
            hEntrada.dHENC_FINICIOREAL = (DateTime)entrada.dENTC_FINICIO;
            hEntrada.id = entrada.id;
            hEntrada.sHENC_PROVEEDOR = entrada.sENTC_PROVEEDOR;
            hEntrada.sHENC_MUELLE = entrada.sENTC_MUELLE;
            hEntrada.sHENC_NALBARAN = entrada.sENTC_NALBARAN;
            hEntrada.sHENC_NPEDIDO = entrada.sENTC_NPEDIDO;
            hEntrada.sHENC_PRIORIDAD = entrada.sENTC_PRIORIDAD;
            hEntrada.sHENC_TRANSPORTISTA = entrada.sENTC_TRANSPORTISTA;
            hEntrada.sHENC_USUARIO = Session["LogedUserFullname"].ToString();

            if (TryValidateModel(hEntrada))
            {
                hEntrada.Guardar();
            }

            foreach (var item in entrada.ENTL)
            {
                HENL lhEntrada = new HENL();
                lhEntrada.id = item.id;
                lhEntrada.sHENL_CANTIDAD = item.sENTL_CANTIDAD;
                lhEntrada.sHENL_CODARTICULO = item.sENTL_CODARTICULO;
                lhEntrada.sHENL_EAN = item.sENTL_EAN;
                lhEntrada.sHENL_FORMATO = item.sENTL_FORMATO;
                lhEntrada.sHENL_IDENTRADA = item.sENTL_IDENTRADA;
                lhEntrada.dHENL_FENTRADA = DateTime.Now;
                lhEntrada.sHENL_USUARIO = Session["LogedUserFullname"].ToString();
                lhEntrada.Guardar();
            }

            entrada.Eliminar(entrada.id);

            return RedirectToAction("IndexT", "Home");
        }

        //Procesar pedido salida
        //Crea el historico en base a la informacion de un pedido, y añade sus lineas
        public ActionResult ProcesarSalida(int codigo)
        {
            SALC salida = salidas.Obtener(codigo);
            salida.dSALC_FFIN = DateTime.Now;
            HSAC hSalida = new HSAC();
            hSalida.bHSAC_AUTOMATICO = salida.bSALC_AUTOMATICO;
            hSalida.dHSAC_FECHA = salida.dSALC_FECHA;
            hSalida.dHSAC_FFIN = (DateTime) salida.dSALC_FFIN;
            hSalida.dHSAC_FFINREAL = (DateTime) salida.dSALC_FFIN;
            hSalida.dHSAC_FINICIO = (DateTime) salida.dSALC_FINICIO;
            hSalida.dHSAC_FINICIOREAL = (DateTime) salida.dSALC_FINICIO;
            hSalida.id = salida.id;
            hSalida.sHSAC_CLIENTE = salida.sSALC_CLIENTE;
            hSalida.sHSAC_MUELLEPLAYA = salida.sSALC_MUELLEPLAYA;
            hSalida.sHSAC_NALBARAN = salida.sSALC_NALBARAN;
            hSalida.sHSAC_NPEDIDO = salida.sSALC_NPEDIDO;
            hSalida.sHSAC_PRIORIDAD = salida.sSALC_PRIORIDAD;
            hSalida.sHSAC_TRANSPORTISTA = salida.sSALC_TRANSPORTISTA;
            hSalida.sHSAC_USUARIO = Session["LogedUserFullname"].ToString();

            if (TryValidateModel(hSalida))
            {
                hSalida.Guardar();
            }
            
            foreach(var item in salida.SALL)
            {
                HSAL lhSalida = new HSAL();
                lhSalida.dHSAL_FSALIDA= DateTime.Now;
                lhSalida.id = item.id;
                lhSalida.sHSAL_CANTIDAD = item.sSALL_CANTIDAD;
                lhSalida.sHSAL_CODARTICULO = item.sSALL_CODARTICULO;
                lhSalida.sHSAL_EAN = item.sSALL_EAN;
                lhSalida.sHSAL_FORMATO = item.sSALL_FORMATO;
                lhSalida.sHSAL_IDSALIDA = item.sSALL_IDSALIDA;
                lhSalida.sHSAL_USUARIO = Session["LogedUserFullname"].ToString();
                lhSalida.Guardar();
            }
           
            salida.Eliminar(salida.id);

            return RedirectToAction("IndexT", "Home");
        }

        //Ver Inventario
        public ActionResult Inventario()
        {
            return View(inventario.Listar());
        }

        public ActionResult DetalleInventario(int codigo)
        {
            return View(inventario.Obtener(codigo));
        }

        //Agregar a inventario
        public ActionResult AddInventario(int codigo=0)
        {
            return View(codigo != 0 ? inventario.Obtener(codigo) : inventario);
        }

        //Eliminar de inventario
        public ActionResult DelInventario(int codigo)
        {
            inventario.Eliminar(codigo);
            return RedirectToAction("Inventario", "Terminal");
        }
       
        //Guardar cambios
        public ActionResult GuardarInventario(UBCI inventario)
        {
            if(ModelState.IsValid)
            {
                try
                {
                    inventario.iUBCI_FECHAALM = DateTime.Now; //Asignamos la fechahora aquí, ya que desde el formulario no se recibe

                    //Controlamos los valores recibidos desde el formulario y los formateamos adecuadamente
                    if (inventario.sUBCI_ALMACEN.Length == 1) inventario.sUBCI_ALMACEN = string.Concat("0", inventario.sUBCI_ALMACEN);
                    if (inventario.sUBCI_ZONA.Length == 1) inventario.sUBCI_ZONA = string.Concat("0", inventario.sUBCI_ZONA);
                    if (inventario.sUBCI_ESTANTERIA.Length == 1)
                    {
                        inventario.sUBCI_ESTANTERIA = string.Concat("00", inventario.sUBCI_ESTANTERIA);
                    }
                    else if(inventario.sUBCI_ESTANTERIA.Length == 2)
                    {
                        inventario.sUBCI_ESTANTERIA = string.Concat("0", inventario.sUBCI_ESTANTERIA);
                    }

                    if (inventario.sUBCI_PROFUNDIDAD.Length == 1)
                    {
                        inventario.sUBCI_PROFUNDIDAD = string.Concat("00", inventario.sUBCI_PROFUNDIDAD);
                    }
                    else if (inventario.sUBCI_PROFUNDIDAD.Length == 2)
                    {
                        inventario.sUBCI_PROFUNDIDAD = string.Concat("0", inventario.sUBCI_PROFUNDIDAD);
                    }

                    if (inventario.sUBCI_ALTURA.Length == 1) inventario.sUBCI_ALTURA = string.Concat("0", inventario.sUBCI_ALTURA);

                    //========

                    UBCM ubicacion = new Models.UBCM();
                    var result = ubicacion.ObtenerOpcionesUbicacion(inventario.sUBCI_ALMACEN, inventario.sUBCI_ZONA, inventario.sUBCI_ESTANTERIA, inventario.sUBCI_PROFUNDIDAD, inventario.sUBCI_ALTURA);
                    if (result != null)
                    {
                        inventario.Guardar();
                    }
                    else
                    {
                        ModelState.AddModelError("", Localization.Localize("datosIncorrectos")); //adicionar mensaje de error al modelo
                        return View("~/views/terminales/AddInventario.cshtml", inventario);
                    }
                }
                catch (Exception e)
                {
                    ModelState.AddModelError("", Localization.Localize("excepcionCreacion")); //adicionar mensaje de error al modelo
                    return View("~/views/terminales/AddInventario.cshtml", inventario);
                }

                return RedirectToAction("Inventario", "Terminal");
            }
            else
            {
                ModelState.AddModelError("", Localization.Localize("datosIncorrectos")); //adicionar mensaje de error al modelo
                return View("~/views/terminales/AddInventario.cshtml", inventario);
            }
            
        }

        //Atender pedido de entrada
        public ActionResult Entrada()
        {
            return View();
        }

        //Atender pedido de salida
        public ActionResult Salida()
        {
            return View();
        }
    }
}