﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.Mvc;
using SGA.Models;
using System.ComponentModel.DataAnnotations;
using Insya.Localization;
using Insya.Localization.Attributes;

namespace SGA.Controllers
{
    public enum OrdenacionZonas
    {
        Estanteria =1,
        Pasillo =2,
        Playa=10
    }

    public class UbicacionesModel
    {
        public string Almacen { get; set; }
        public string Zona { get; set; }
        public string Estanteria { get; set; }
    }


    public class UbicacionesController : BaseController
    {
        private UBCA almacen = new UBCA();
        private UBCZ zona = new UBCZ();
        private UBCM ubicacion = new UBCM();

        #region "Funciones internas del controlador"

        /// <summary>
        /// Funcion que devuelve una lista de strings, partiendo de un string original.
        /// Se indica cuantos caracteres tiene que tener el string (los faltantes se rellenan con 0 desde la izquierda)
        /// y se devuelven tantos string como indica el tercer parametro.
        /// </summary>
        /// <param name="numCaracteres"></param>
        /// <param name="strOriginal"></param>
        /// <param name="numMovimientos"></param>
        /// <returns></returns>
        public List<string> ContadorAlfanumerico(int numCaracteres, string strOriginal, int numMovimientos)
        {
            int numC = strOriginal.Length;
            numC = numCaracteres - numC;

            for (int ceros = 1; ceros <= numC; ceros++)
            {
                strOriginal = string.Concat("0", strOriginal);
            }

            string strFormateado = strOriginal;
            List<string> listado = new List<string>();
            char[] strArray;

            for (int i = 1; i <= numMovimientos; i++)
            {
                strArray = strFormateado.ToCharArray();
                for (int n = strArray.Length-1; n >= 0; n--)
                {
                    if (strArray[n] == '9')
                    {
                        if (n == 0)
                        {
                            strArray[n] = 'A';
                            break;
                        }
                        else
                        {
                            if (strArray[n - 1] == 'Z')
                            {
                                strArray[n] = 'A';
                            }
                            else
                            {
                                strArray[n] = '0';
                            }
                        }

                    }
                    else if (strArray[n] != 'Z')
                    {
                        strArray[n]++;
                        break;
                    }
                    
                }

                strFormateado = new string(strArray);
                listado.Add(strFormateado);
            }     
            
            return listado;
        }

        #endregion

        public ActionResult Index()
        {
            return View(almacen.Listar());
        }

        public ActionResult CrudAlmacen(int cantidad)
        {
            var MaxId = Convert.ToInt32(almacen.ObtenerMax().Substring(1));
            return View();
        }

        public ActionResult CrudZona(int cantidad)
        {
            return View();
        }

        [ActionName("ZonasPorAlmacen")]
        public JsonResult GetZonasPorAlmacen(string almacen)
        {
            List<UBCZ> zonas = zona.ObtenerPorAlmacen(almacen);
            return Json(zonas, JsonRequestBehavior.AllowGet) ;
        }

        [ActionName("EstantesPorZona")]
        public JsonResult GetEstantesPorZona(UbicacionesModel model)
        {
            List<UBCM> estanterias = ubicacion.ObtenerEstanteriasPorZona(model.Zona, model.Almacen);
            return Json(estanterias, JsonRequestBehavior.AllowGet);
        }

        [ActionName("UbicacionesPorEstante")]
        public JsonResult GetUbicacionesPorEstante(UbicacionesModel model)
        {
            var ordenacion = zona.ObtenerOrdenacion(model.Almacen, model.Zona);
            List<UBCM> ubicaciones = ubicacion.ObtenerUbicacionesPorEstante(model.Zona, model.Estanteria, model.Almacen);

            try
            {
                List<UBCM> izquierda = new List<UBCM>();
                List<UBCM> derecha = new List<UBCM>();
                switch ((OrdenacionZonas)ordenacion)
                {
                    case OrdenacionZonas.Pasillo:
                        for(int i = 0; i <= ubicaciones.Count-1; i++)
                        {
                            if((i+1) %2 ==0)
                            {
                                derecha.Add(ubicaciones[i]);
                            }
                            else
                            {
                                izquierda.Add(ubicaciones[i]);
                            }
                        }
                        ubicaciones.Clear();
                        ubicaciones.AddRange(izquierda);
                        ubicaciones.AddRange(derecha);
                        break;
                }

            }
            catch (Exception ex)
            {

            }

            return Json(ubicaciones, JsonRequestBehavior.AllowGet);
        }

        [HttpPost]
        [ActionName("AddAlmacen")]
        public JsonResult AddAlmacen(UBCA model)
        {
           var response = new ResponseModel();

            if (model != null && model.sUBCA_ALMACEN != null)
            {
                if (model.sUBCA_ALMACEN.Length == 1)
                {
                    model.sUBCA_ALMACEN = string.Concat("0", model.sUBCA_ALMACEN);
                }
                
            }

            try
            {

                if(model.sUBCA_ALMACEN == string.Empty)
                {
                    throw new Exception();
                }

                model.Guardar();
            }
            catch (Exception ex)
            {
                response.Error = true;
                response.Mensaje = Localization.Localize("excepcionValidacion");
            }

            return Json(response);
        }

        [HttpPost]
        [ActionName("AddZona")]
        public JsonResult AddZona(UBCZ model)
        {
            var response = new ResponseModel();

            if (model != null && model.sUBCZ_ZONA != null)
            {
                if (model.sUBCZ_ZONA.Length == 1)
                {
                    model.sUBCZ_ZONA = string.Concat("0", model.sUBCZ_ZONA);
                }

            }

            try
            {

                if (model.sUBCZ_ZONA == string.Empty)
                {
                    throw new Exception();
                }

                model.Guardar();
            }
            catch (Exception ex)
            {
                response.Error = true;
                response.Mensaje = Localization.Localize("excepcionValidacion");
            }

            return Json(response);
        }

        [HttpPost]
        [ActionName("GetOrdenacion")]
        public JsonResult GetOrdenacion(UBCZ model)
        {
            var response = new ResponseModel();
            try
            {
                response.Mensaje = zona.ObtenerOrdenacion(model.sUBCZ_ALMACEN, model.sUBCZ_ZONA).ToString();
            }
            catch (Exception ex)
            {
                response.Error = true;
                response.Mensaje = Localization.Localize("excepcionValidacion");
            }

            return Json(response);
        }

        [HttpPost]
        [ActionName("GetOpcionesUbicacion")]
        public JsonResult GetOpcionesUbicacion(UBCM model)
        {
            UBCM response;
            response = ubicacion.ObtenerOpcionesUbicacion(model.sUBCM_ALMACEN, model.sUBCM_ZONA, model.sUBCM_ESTANTERIA, model.sUBCM_PROFUNDIDAD, model.sUBCM_ALTURA);
            return Json(response);
        }

        [HttpPost]
        [ActionName("GuardarOpcionesUbicacion")]
        public JsonResult GuardarOpcionesUbicacion(UBCM model)
        {
            var response = new ResponseModel();
            try
            {
                model.Guardar();
            }
            catch (Exception ex)
            {
                response.Error = true;
                response.Mensaje = Localization.Localize("excepcionValidacion");
            }

            return Json(response);
        }

        [HttpPost]
        [ActionName("AddUbicaciones")]
        public JsonResult AddUbicaciones(UBCM model)
        {
            var response = new ResponseModel();
            try
            { 
                var idMax= ubicacion.ObtenerMax(model.sUBCM_ALMACEN, model.sUBCM_ZONA);
                if (idMax==null)
                {
                    model.sUBCM_ESTANTERIA = "001";
                }
                else
                {
                    model.sUBCM_ESTANTERIA = ContadorAlfanumerico(3, idMax, 1).First();
                }

                OrdenacionZonas ordenacion = (OrdenacionZonas)zona.ObtenerOrdenacion(model.sUBCM_ALMACEN, model.sUBCM_ZONA);
                List<string> profundidades;
                List<string> alturas;
                switch (ordenacion)
                {
                    case OrdenacionZonas.Estanteria:
                        profundidades = ContadorAlfanumerico(3,"0", Convert.ToInt32(model.sUBCM_PROFUNDIDAD));
                        alturas = ContadorAlfanumerico(2,"0", Convert.ToInt32(model.sUBCM_ALTURA));

                        foreach (string altura in alturas)
                        {
                            foreach (string profundidad in profundidades)
                            {
                                model.id = 0; //Para poder reutilizar en adicion
                                model.sUBCM_PROFUNDIDAD = profundidad;
                                model.sUBCM_ALTURA = altura;
                                model.Guardar();
                            }
                        }

                        break;

                    case OrdenacionZonas.Pasillo:
                        //Las ubicaciones en pasillo, se consideran como una estanteria doble, ya que hay que añadir las mismas ubicaciones
                        //a izquierda y derecha del pasillo, por tanto, la profundidad será doble = doble numero de ubicaciones.
                        profundidades = ContadorAlfanumerico(3, "0", Convert.ToInt32(model.sUBCM_PROFUNDIDAD)*2);
                        alturas = ContadorAlfanumerico(2, "0", Convert.ToInt32(model.sUBCM_ALTURA));

                        foreach (string altura in alturas)
                        {
                            foreach (string profundidad in profundidades)
                            {
                                model.id = 0; //Para poder reutilizar en adicion
                                model.sUBCM_PROFUNDIDAD = profundidad;
                                model.sUBCM_ALTURA = altura;
                                model.Guardar();
                            }
                        }

                        break;
                }

            }
            catch (Exception ex)
            {
                response.Error = true;
                response.Mensaje = Localization.Localize("excepcionGeneracionUbicaciones");
            }

            return Json(response);
        }
    }
}
