﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.Mvc;
using SGA.Models;
using Insya.Localization;

namespace SGA.Controllers
{
    public class UserController : BaseController
    {
        private USRS usuario = new USRS();
        private UserProfileModel userProfile = new UserProfileModel(); //Para pasar listados y el modelo a la vista de crud de usuarios
        
        /// <summary>
        /// Principal
        /// </summary>
        /// <returns></returns>
        public ActionResult Index()
        {
            return View(usuario.Listar());
        }

        /// <summary>
        /// Rellena los listados para los combobox del perfil de usuario
        /// </summary>
        /// <param name="user"></param>
        /// <returns></returns>
        private UserProfileModel RellenarUserProfile(USRS user)
        {
            List<SelectListItem> rolSelectListItems = new List<SelectListItem>();
            List<SelectListItem> langSelectListItems = new List<SelectListItem>();

            SelectListItem admin = new SelectListItem() { Text = Localization.Localize("admin"), Value = "1", Selected = (user != null ? user.sUSRS_ROL == 1 : false) };
            SelectListItem terminal = new SelectListItem() { Text = Localization.Localize("terminal"), Value = "2", Selected = (user != null ? user.sUSRS_ROL == 2 : true) };

            rolSelectListItems.Add(admin);
            rolSelectListItems.Add(terminal);

            SelectListItem es = new SelectListItem() { Text = "Español", Value = "es_ES", Selected = (user != null ? user.sUSRS_CULTURA == "es_ES" : true) };
            SelectListItem eus = new SelectListItem() { Text = "Euskera", Value = "eu_ES", Selected = (user != null ? user.sUSRS_CULTURA == "eu_ES" : false) };
            SelectListItem en = new SelectListItem() { Text = "English", Value = "en_US", Selected = (user != null ? user.sUSRS_CULTURA == "en_US" : false) };

            langSelectListItems.Add(es);
            langSelectListItems.Add(eus);
            langSelectListItems.Add(en);

            userProfile.Roles = rolSelectListItems;
            userProfile.Culturas = langSelectListItems;
            userProfile.USRS = user;

            return userProfile;
        }

        /// <summary>
        /// Creación o edición de usuarios
        /// </summary>
        /// <param name="user"></param>
        /// <returns></returns>
        public ActionResult Crud(string user = null)
        {
            USRS usuarioObtenido = new USRS();
            usuarioObtenido= (user != null) ? usuarioObtenido=usuario.Obtener(user) : usuario;
            userProfile=RellenarUserProfile(usuarioObtenido);

            return View(userProfile);
        }

        /// <summary>
        /// Ver perfil del usuario
        /// </summary>
        /// <param name="user"></param>
        /// <returns></returns>
        public ActionResult Ver(string user)
        {
            return View(usuario.Obtener(user));
        }


        /// <summary>
        /// Guarda el usuario recibido desde el formulario de creación de usuarios
        /// </summary>
        /// <param name="userProfile"></param>
        /// <returns></returns>
        public ActionResult Guardar(UserProfileModel userProfile)
        {
            if (userProfile.USRS.sUSRS_PASSWORD != null) { userProfile.USRS.SetPasswordHashAndSalt(); } 
            if (TryValidateModel(userProfile.USRS))
            {
                try
                {
                    userProfile.USRS.Guardar();
                    return Redirect("~/user/ver/" + userProfile.USRS.sUSRS_USUARIO);
                }
                catch (Exception)
                {
                    ModelState.AddModelError("", Localization.Localize("excepcionCreacion")); //adicionar mensaje de error al modelo
                    userProfile = RellenarUserProfile(userProfile.USRS);
                    return View("~/Views/User/Crud.cshtml", userProfile);
                }
               
            }
            else
            {
                userProfile= RellenarUserProfile(userProfile.USRS);
                return View("~/Views/User/Crud.cshtml", userProfile);
            }
           
        }

        /// <summary>
        /// Eliminar usuarios
        /// </summary>
        /// <param name="user"></param>
        /// <returns></returns>
        public ActionResult Eliminar(string user)
        {
            usuario.Eliminar(user);
            return Redirect("~/user");
        }

        [HttpGet]
        public ActionResult Login()
        {
            return View();
        }

        /// <summary>
        /// Verificar los datos suministrados por el usuario al realizar la petición Post de envio de información
        /// mediante la GUI de Autenticación de la aplicación.
        /// </summary>
        /// <param name=”user”></param>
        /// <returns></returns>
        [HttpPost]
        public ActionResult Login(USRS loginUser)
        {
            USRS user =null;
            if (ModelState.IsValidField("sUSRS_USUARIO") && ModelState.IsValidField("sUSRS_PASSWORD"))
            {
                
                try
                {
                    user = usuario.Obtener(loginUser.sUSRS_USUARIO);
                }
                catch(Exception ex)
                {
                    //Si no se encuentra el usuario, habra una excepcion
                    ModelState.AddModelError("", Localization.Localize("datosIncorrectos")); //adicionar mensaje de error al model
                    return View(loginUser);
                }

                if (user.sUSRS_PASSWORD == user.HashPassword(loginUser.sUSRS_PASSWORD, user.sUSRS_SALT)) //Verificar que existe
                {
                    //FormsAuthentication.SetAuthCookie(usuario.sUSRS_USUARIO,false); //crea variable de usuario con el correo del usuario
                    if(user.sUSRS_ACTIVO)
                    {
                        Session["LogedUserID"] = user.id;
                        Session["LogedUserFullname"] = user.sUSRS_USUARIO;
                        Session["Role"] = user.sUSRS_ROL;

                        Response.Cookies["CacheLang"].Value = user.sUSRS_CULTURA;
                        if (user.sUSRS_ROL == 1)
                        {
                            return RedirectToAction("Index", "Home"); //dirigir al home de gestion    
                        }
                        else
                        {
                            return RedirectToAction("IndexT", "Home"); //dirigir al home de terminales
                        }
                                   
                    }
                    else
                    {
                        ModelState.AddModelError("", Localization.Localize("usuarioInactivo")); //adicionar mensaje de error al model
                    }
                    
                }
                else
                {
                    ModelState.AddModelError("", Localization.Localize("datosIncorrectos")); //adicionar mensaje de error al model
                }

                return View(loginUser);
            }
            else
            {
                return View("~/Views/User/Login.cshtml", loginUser);
            }
            
        }

        /// <summary>
        /// Cerrar sesión del usuario autenticado
        /// </summary>
        /// <returns></returns>
        public ActionResult Logout()
        {
            Session.Clear();
            return RedirectToAction("Index","Home");
        }


        //public ActionResult ChangeCurrentCulture(int culture)
        //{
        //    //
        //    // Change the current culture for this user.
        //    //
        //    System.Threading.Thread.CurrentThread.CurrentUICulture = new System.Globalization.CultureInfo("es-ES");
        //    //
        //    // Cache the new current culture into the user HTTP session. 
        //    //
        //    Session["CurrentUICulture"] = culture;
        //    //
        //    // Redirect to the same page from where the request was made! 
        //    //
        //    return Redirect(Request.UrlReferrer.ToString());
        //}
    }
}