namespace SGA.Models
{
    using Insya.Localization.Attributes;
    using System;
    using System.Collections.Generic;
    using System.ComponentModel.DataAnnotations;
    using System.ComponentModel.DataAnnotations.Schema;
    using System.Data.Entity.Spatial;
    using System.Linq;

    [Table("ARTC")]
    public partial class ARTC
    {
        [DatabaseGenerated(DatabaseGeneratedOption.Identity)]
        public int id { get; set; }

        [System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Usage", "CA2214:DoNotCallOverridableMethodsInConstructors")]
        public ARTC()
        {
            ARTF = new List<ARTF>();
        }

        [Key]
        [RequiredLocalized]
        [StringLength(50)]
        public string sARTC_CODIGO { get; set; }

        [RequiredLocalized]
        public string sARTC_DESCRIPCION { get; set; }

        [Column(TypeName = "numeric")]
        [RequiredLocalized]
        [DisplayFormat(DataFormatString ="{0}")]
        public decimal sARTC_EAN { get; set; }

        public bool bART_FIFO { get; set; }

        public bool bART_LIFO { get; set; }

        public bool bART_LOTE { get; set; }

        [System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Usage", "CA2227:CollectionPropertiesShouldBeReadOnly")]
        public virtual List<ARTF> ARTF { get; set; }

        public List<ARTC> Listar()
        {
            var articulos = new List<ARTC>();
            try
            {
                using (var context = new SGAContext())
                {
                    articulos = context.ARTC.ToList();
                }
            }
            catch (Exception e)
            {
                throw new Exception(e.Message);
            }
            return articulos;
        }

        public ARTC Obtener(string codigo)
        {
            var articulo = new ARTC();
            try
            {
                using (var context = new SGAContext())
                {
                    articulo = context.ARTC
                        .Include("ARTF")
                        .Where(x => x.sARTC_CODIGO == codigo)
                        .Single();
                }
            }
            catch (Exception e)
            {
                throw new Exception(e.Message);
            }
            return articulo;
        }

        public void Guardar()
        {
            try
            {
                using (var context = new SGAContext())
                {
                    if (this.id == 0)
                    {
                        context.Entry(this).State = System.Data.Entity.EntityState.Added;
                    }
                    else
                    {
                        context.Entry(this).State = System.Data.Entity.EntityState.Modified;
                    }

                    context.SaveChanges();
                }
            }
            catch (Exception e)
            {
                throw new Exception(e.Message);
            }
        }

        public void Eliminar(string codigo)
        {
            try
            {
                using (var context = new SGAContext())
                {
                    context.Entry(new ARTC { sARTC_CODIGO= codigo }).State = System.Data.Entity.EntityState.Deleted;
                    context.SaveChanges();
                }
            }
            catch (Exception e)
            {
                throw new Exception(e.Message);
            }
        }
    }
}
