namespace SGA.Models
{
    using System;
    using System.Collections.Generic;
    using System.ComponentModel.DataAnnotations;
    using System.ComponentModel.DataAnnotations.Schema;
    using System.Data.Entity.Spatial;
    using System.Linq;

    [Table("ARTF")]
    public partial class ARTF
    {
        [DatabaseGenerated(DatabaseGeneratedOption.Identity)]
        public int id { get; set; }

        [Key]
        [Column(Order = 0)]
        [StringLength(50)]
        public string sARTF_CODIGO { get; set; }

        public bool bARTF_EAN { get; set; }

        [Column(TypeName = "numeric")]
        [DisplayFormat(DataFormatString = "{0}")]
        public decimal? iARTF_DUN14 { get; set; }

        [Key]
        [Column(Order = 1, TypeName = "numeric")]
        public decimal iARTF_NFORMATO { get; set; }

        [Column(TypeName = "numeric")]
        public decimal iARTF_CANTIDAD { get; set; }

        public bool bARTF_MATRICULA { get; set; }

        [StringLength(50)]
        public string sARTF_MATRICULA { get; set; }

        [Column(TypeName = "numeric")]
        public decimal iARTF_PESO { get; set; }

        public virtual ARTC ARTC { get; set; }

        public List<ARTF> Listar()
        {
            var formatos = new List<ARTF>();
            try
            {
                using (var context = new SGAContext())
                {
                    formatos = context.ARTF.ToList();
                }
            }
            catch (Exception e)
            {
                throw new Exception(e.Message);
            }
            return formatos;
        }

        public ARTF Obtener(string codigo, decimal nFormato)
        {
            var formato = new ARTF();
            try
            {
                using (var context = new SGAContext())
                {
                    formato = context.ARTF
                        .Where(x => x.sARTF_CODIGO == codigo & x.iARTF_NFORMATO == nFormato)
                        .Single();
                }
            }
            catch (Exception e)
            {
                throw new Exception(e.Message);
            }
            return formato;
        }

        public void Guardar()
        {
            try
            {
                using (var context = new SGAContext())
                {
                    if (this.id == 0)
                    {
                        context.Entry(this).State = System.Data.Entity.EntityState.Added;
                    }
                    else
                    {
                        context.Entry(this).State = System.Data.Entity.EntityState.Modified;
                    }

                    context.SaveChanges();
                }
            }
            catch (Exception e)
            {
                throw new Exception(e.Message);
            }
        }

        public void Eliminar(string codigo, decimal nFormato)
        {
            try
            {
                using (var context = new SGAContext())
                {
                    context.Entry(new ARTF { sARTF_CODIGO = codigo, iARTF_NFORMATO = nFormato }).State = System.Data.Entity.EntityState.Deleted;
                    context.SaveChanges();
                }
            }
            catch (Exception e)
            {
                throw new Exception(e.Message);
            }
        }
    }
}
