namespace SGA.Models
{
    using Insya.Localization.Attributes;
    using System;
    using System.Collections.Generic;
    using System.ComponentModel.DataAnnotations;
    using System.ComponentModel.DataAnnotations.Schema;
    using System.Data.Entity.Spatial;
    using System.Linq;

    [Table("ENTC")]
    public partial class ENTC
    {
        [System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Usage", "CA2214:DoNotCallOverridableMethodsInConstructors")]
        public ENTC()
        {
            ENTL = new List<ENTL>();
        }

        public int id { get; set; }

        [StringLength(50)]
        public string sENTC_NPEDIDO { get; set; }

        public DateTime dENTC_FECHA { get; set; }

        public DateTime? dENTC_FINICIO { get; set; }

        public DateTime? dENTC_FFIN { get; set; }

        public string sENTC_PROVEEDOR { get; set; }

        public string sENTC_TRANSPORTISTA { get; set; }

        public bool bENTC_AUTOMATICO { get; set; }

        [RequiredLocalized]
        public string sENTC_USUARIO { get; set; }

        [RequiredLocalized]
        [DisplayFormat(DataFormatString = "{0}")]
        [Column(TypeName = "numeric")]
        public decimal sENTC_PRIORIDAD { get; set; }

        [StringLength(50)]
        public string sENTC_NALBARAN { get; set; }

        [StringLength(50)]
        public string sENTC_MUELLE { get; set; }

        [System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Usage", "CA2227:CollectionPropertiesShouldBeReadOnly")]
        public virtual List<ENTL> ENTL { get; set; }

        public virtual ENTU ENTU { get; set; }

        public List<ENTC> Listar()
        {
            var entradas = new List<ENTC>();
            try
            {
                using (var context = new SGAContext())
                {
                    entradas = context.ENTC
                        .Include("ENTU")
                        .OrderByDescending(x =>x.sENTC_PRIORIDAD)
                        .ToList();
                }
            }
            catch (Exception e)
            {
                throw new Exception(e.Message);
            }
            return entradas;
        }

        public ENTC Obtener(int codigo)
        {
            var entrada = new ENTC();
            try
            {
                using (var context = new SGAContext())
                {
                    entrada = context.ENTC
                        .Include("ENTL")
                        .OrderByDescending(x => x.sENTC_PRIORIDAD)
                        .Where(x => x.id == codigo)
                        .Single();
                }
            }
            catch (Exception e)
            {
                throw new Exception(e.Message);
            }
            return entrada;
        }

        public void Guardar()
        {
            try
            {
                using (var context = new SGAContext())
                {
                    if (this.id == 0)
                    {
                        this.dENTC_FECHA = DateTime.Now; //Al ser nueva a�adimos la hora del sistema
                        context.Entry(this).State = System.Data.Entity.EntityState.Added;
                    }
                    else
                    {
                        context.Entry(this).State = System.Data.Entity.EntityState.Modified;
                    }

                    context.SaveChanges();
                }
            }
            catch (Exception e)
            {
                throw new Exception(e.Message);
            }
        }

        public void Eliminar(int codigo)
        {
            try
            {
                using (var context = new SGAContext())
                {
                    context.Entry(new ENTC { id = codigo }).State = System.Data.Entity.EntityState.Deleted;
                    context.SaveChanges();
                }
            }
            catch (Exception e)
            {
                throw new Exception(e.Message);
            }
        }

    }
}
