namespace SGA.Models
{
    using Insya.Localization.Attributes;
    using System;
    using System.Collections.Generic;
    using System.ComponentModel.DataAnnotations;
    using System.ComponentModel.DataAnnotations.Schema;
    using System.Data.Entity.Spatial;
    using System.Linq;
    [Table("SALC")]
    public partial class SALC
    {
        [System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Usage", "CA2214:DoNotCallOverridableMethodsInConstructors")]
        public SALC()
        {
            SALL = new List<SALL>();
        }

        public int id { get; set; }

        [StringLength(50)]
        public string sSALC_NPEDIDO { get; set; }

        public DateTime dSALC_FECHA { get; set; }

        public DateTime? dSALC_FINICIO { get; set; }

        public DateTime? dSALC_FFIN { get; set; }

        public string sSALC_CLIENTE { get; set; }

        public string sSALC_TRANSPORTISTA { get; set; }

        public bool bSALC_AUTOMATICO { get; set; }

        [RequiredLocalized]
        public string sSALC_USUARIO { get; set; }

        [RequiredLocalized]
        [Column(TypeName = "numeric")]
        [DisplayFormat(DataFormatString = "{0}")]
        public decimal sSALC_PRIORIDAD { get; set; }

        [StringLength(50)]
        public string sSALC_NALBARAN { get; set; }

        [StringLength(50)]
        public string sSALC_MUELLEPLAYA { get; set; }

        [System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Usage", "CA2227:CollectionPropertiesShouldBeReadOnly")]
        public virtual List<SALL> SALL { get; set; }

        public virtual SALU SALU { get; set; }

        public List<SALC> Listar()
        {
            var salidas = new List<SALC>();
            try
            {
                using (var context = new SGAContext())
                {
                    salidas = context.SALC
                        .Include("SALU")
                        .OrderByDescending(x => x.sSALC_PRIORIDAD)
                        .ToList();
                }
            }
            catch (Exception e)
            {
                throw new Exception(e.Message);
            }
            return salidas;
        }

        public SALC Obtener(int codigo)
        {
            var salida = new SALC();
            try
            {
                using (var context = new SGAContext())
                {
                    salida = context.SALC
                        .Include("SALL")
                        .OrderByDescending(x => x.sSALC_PRIORIDAD)
                        .Where(x => x.id == codigo)
                        .Single();
                }
            }
            catch (Exception e)
            {
                throw new Exception(e.Message);
            }
            return salida;
        }

        public void Guardar()
        {
            try
            {
                using (var context = new SGAContext())
                {
                    if (this.id == 0)
                    {
                        this.dSALC_FECHA = DateTime.Now; //Al ser nueva a�adimos la hora del sistema
                        context.Entry(this).State = System.Data.Entity.EntityState.Added;
                    }
                    else
                    {
                        context.Entry(this).State = System.Data.Entity.EntityState.Modified;
                    }

                    context.SaveChanges();
                }
            }
            catch (Exception e)
            {
                throw new Exception(e.Message);
            }
        }

        public void Eliminar(int codigo)
        {
            try
            {
                using (var context = new SGAContext())
                {
                    context.Entry(new SALC { id = codigo }).State = System.Data.Entity.EntityState.Deleted;
                    context.SaveChanges();
                }
            }
            catch (Exception e)
            {
                throw new Exception(e.Message);
            }
        }
       
    }
}
