namespace SGA.Models
{
    using Insya.Localization.Attributes;
    using System;
    using System.Collections.Generic;
    using System.ComponentModel.DataAnnotations;
    using System.ComponentModel.DataAnnotations.Schema;
    using System.Data.Entity.Spatial;
    using System.Linq;

    [Table("SALU")]
    public partial class SALU
    {
        [Key]
        [DatabaseGenerated(DatabaseGeneratedOption.None)]
        public int iSALU_id { get; set; }

        [RequiredLocalized]
        [StringLength(50)]
        public string sSALU_USUARIO { get; set; }

        public virtual SALC SALC { get; set; }

        /// <summary>
        /// Obtiene una lista de todos los pedidos de entrada pendientes
        /// </summary>
        /// <returns></returns>
        public List<SALU> Listar()
        {
            var entradas = new List<SALU>();
            try
            {
                using (var context = new SGAContext())
                {
                    entradas = context.SALU
                        .Include("SALC")
                        .ToList();
                }
            }
            catch (Exception e)
            {
                throw new Exception(e.Message);
            }
            return entradas;
        }

        /// <summary>
        /// Obtiene una lista de todos los pedidos de entrada asignados al usuario
        /// </summary>
        /// <param name="usuario"></param>
        /// <returns></returns>
        public List<SALU> ListarByUser(string usuario)
        {
            var entradas = new List<SALU>();
            try
            {
                using (var context = new SGAContext())
                {
                    entradas = context.SALU
                        .Include("SALC")
                        .Where(x => x.sSALU_USUARIO == usuario)
                        .OrderBy(y => y.iSALU_id)
                        .ToList();
                }
            }
            catch (Exception e)
            {
                throw new Exception(e.Message);
            }
            return entradas;
        }

        public void Guardar()
        {
            try
            {
                using (var context = new SGAContext())
                {
                    context.Entry(this).State = System.Data.Entity.EntityState.Added;
                    context.SaveChanges();
                }
            }
            catch (Exception e)
            {
                throw new Exception(e.Message);
            }
        }
    }
}
