namespace SGA.Models
{
    using System;
    using System.Data.Entity;
    using System.ComponentModel.DataAnnotations.Schema;
    using System.Linq;

    public partial class SGAContext : DbContext
    {
        public SGAContext()
            : base("name=SGAContext")
        {
        }

        public virtual DbSet<ARTC> ARTC { get; set; }
        public virtual DbSet<ARTF> ARTF { get; set; }
        public virtual DbSet<USRS> USRS { get; set; }
        public virtual DbSet<UBCA> UBCA { get; set; }
        public virtual DbSet<UBCI> UBCI { get; set; }
        public virtual DbSet<UBCM> UBCM { get; set; }
        public virtual DbSet<UBCZ> UBCZ { get; set; }

        public virtual DbSet<ZONA> ZONA { get; set; }

        public virtual DbSet<ENTC> ENTC { get; set; }
        public virtual DbSet<ENTL> ENTL { get; set; }
        public virtual DbSet<SALC> SALC { get; set; }
        public virtual DbSet<SALL> SALL { get; set; }

        public virtual DbSet<ENTU> ENTU { get; set; }
        public virtual DbSet<HENC> HENC { get; set; }
        public virtual DbSet<HENL> HENL { get; set; }
        public virtual DbSet<HSAC> HSAC { get; set; }
        public virtual DbSet<HSAL> HSAL { get; set; }
        public virtual DbSet<SALU> SALU { get; set; }
        public virtual DbSet<HUBI> HUBI { get; set; }

        protected override void OnModelCreating(DbModelBuilder modelBuilder)
        {
            modelBuilder.Entity<ARTC>()
                .Property(e => e.sARTC_EAN)
                .HasPrecision(18, 0);

            modelBuilder.Entity<ARTC>()
                .HasMany(e => e.ARTF)
                .WithRequired(e => e.ARTC)
                .HasForeignKey(e => e.sARTF_CODIGO);

            modelBuilder.Entity<ARTF>()
                .Property(e => e.iARTF_DUN14)
                .HasPrecision(18, 0);

            modelBuilder.Entity<ARTF>()
                .Property(e => e.iARTF_NFORMATO)
                .HasPrecision(2, 0);

            modelBuilder.Entity<ARTF>()
                .Property(e => e.iARTF_CANTIDAD)
                .HasPrecision(3, 0);

            modelBuilder.Entity<ARTF>()
                .Property(e => e.iARTF_PESO)
                .HasPrecision(6, 2);

            modelBuilder.Entity<UBCA>()
               .HasMany(e => e.UBCZ)
               .WithRequired(e => e.UBCA)
               .HasForeignKey(e => e.sUBCZ_ALMACEN);

            modelBuilder.Entity<UBCI>()
                .Property(e => e.iUBCI_CANTIDAD)
                .HasPrecision(3, 0);

            modelBuilder.Entity<UBCZ>()
                .HasMany(e => e.UBCM)
                .WithRequired(e => e.UBCZ)
                .HasForeignKey(e => new { e.sUBCM_ALMACEN, e.sUBCM_ZONA });

            modelBuilder.Entity<ENTC>()
               .Property(e => e.sENTC_PRIORIDAD)
               .HasPrecision(2, 0);

            modelBuilder.Entity<ENTC>()
                .HasMany(e => e.ENTL)
                .WithRequired(e => e.ENTC)
                .HasForeignKey(e => e.sENTL_IDENTRADA);

            modelBuilder.Entity<ENTC>()
               .HasOptional(e => e.ENTU)
               .WithRequired(e => e.ENTC)
               .WillCascadeOnDelete();

            modelBuilder.Entity<ENTL>()
                .Property(e => e.sENTL_EAN)
                .HasPrecision(18, 0);

            modelBuilder.Entity<ENTL>()
                .Property(e => e.sENTL_FORMATO)
                .HasPrecision(2, 0);

            modelBuilder.Entity<SALC>()
                .Property(e => e.sSALC_PRIORIDAD)
                .HasPrecision(2, 0);

            modelBuilder.Entity<SALC>()
                .HasMany(e => e.SALL)
                .WithRequired(e => e.SALC)
                .HasForeignKey(e => e.sSALL_IDSALIDA);

            modelBuilder.Entity<SALC>()
               .HasOptional(e => e.SALU)
               .WithRequired(e => e.SALC)
               .WillCascadeOnDelete();

            modelBuilder.Entity<SALL>()
                .Property(e => e.sSALL_EAN)
                .HasPrecision(18, 0);

            modelBuilder.Entity<SALL>()
                .Property(e => e.sSALL_FORMATO)
                .HasPrecision(2, 0);

            modelBuilder.Entity<HENC>()
               .Property(e => e.sHENC_PRIORIDAD)
               .HasPrecision(2, 0);

            modelBuilder.Entity<HENC>()
                .HasMany(e => e.HENL)
                .WithRequired(e => e.HENC)
                .HasForeignKey(e => e.sHENL_IDENTRADA)
                .WillCascadeOnDelete(false);

            modelBuilder.Entity<HENL>()
                .Property(e => e.sHENL_EAN)
                .HasPrecision(18, 0);

            modelBuilder.Entity<HENL>()
                .Property(e => e.sHENL_CANTIDAD)
                .HasPrecision(3, 0);

            modelBuilder.Entity<HENL>()
                .Property(e => e.sHENL_FORMATO)
                .HasPrecision(2, 0);

            modelBuilder.Entity<HSAC>()
                .Property(e => e.sHSAC_PRIORIDAD)
                .HasPrecision(2, 0);

            modelBuilder.Entity<HSAC>()
                .HasMany(e => e.HSAL)
                .WithRequired(e => e.HSAC)
                .HasForeignKey(e => e.sHSAL_IDSALIDA)
                .WillCascadeOnDelete(false);

            modelBuilder.Entity<HSAL>()
                .Property(e => e.sHSAL_EAN)
                .HasPrecision(18, 0);

            modelBuilder.Entity<HSAL>()
                .Property(e => e.sHSAL_CANTIDAD)
                .HasPrecision(3, 0);

            modelBuilder.Entity<HSAL>()
                .Property(e => e.sHSAL_FORMATO)
                .HasPrecision(2, 0);

            modelBuilder.Entity<HUBI>()
                .Property(e => e.iHUBI_CANTIDAD)
                .HasPrecision(3, 0);

        }
    }
}
