namespace SGA.Models
{
    using System;
    using System.Collections.Generic;
    using System.ComponentModel.DataAnnotations;
    using System.ComponentModel.DataAnnotations.Schema;
    using System.Data.Entity.Spatial;
    using System.Linq;

    [Table("UBCM")]
    public partial class UBCM
    {
        [DatabaseGenerated(DatabaseGeneratedOption.Identity)]
        public int id { get; set; }

        [Key]
        [Column(Order = 0)]
        [StringLength(2)]
        public string sUBCM_ALMACEN { get; set; }

        [Key]
        [Column(Order = 1)]
        [StringLength(2)]
        public string sUBCM_ZONA { get; set; }

        [Key]
        [Column(Order = 2)]
        [StringLength(3)]
        public string sUBCM_ESTANTERIA { get; set; }

        [Key]
        [Column(Order = 3)]
        [StringLength(3)]
        public string sUBCM_PROFUNDIDAD { get; set; }

        [Key]
        [Column(Order = 4)]
        [StringLength(2)]
        public string sUBCM_ALTURA { get; set; }

        public bool bUBCM_MONOPRODUCTO { get; set; }

        public bool bUBCM_BLOQUEADO { get; set; }

        public virtual UBCZ UBCZ { get; set; }

        public List<UBCM> Listar()
        {
            var ubicaciones = new List<UBCM>();
            try
            {
                using (var context = new SGAContext())
                {
                    ubicaciones = context.UBCM.ToList();
                }
            }
            catch (Exception e)
            {
                throw new Exception(e.Message);
            }
            return ubicaciones;
        }

        public List<UBCM> ObtenerEstanteriasPorZona(string zona, string almacen)
        {
            var estanterias = new List<UBCM>();
            try
            {
                using (var context = new SGAContext())
                {
                    context.Configuration.LazyLoadingEnabled = false;
                    //Se desactiva lazyloading para que no haya problemas con la muerte del contexto al llegar al procesamiento en jQuery
                    estanterias = context.UBCM
                        .Where(x => x.sUBCM_ZONA == zona & x.sUBCM_ALMACEN==almacen)
                        .GroupBy(y => y.sUBCM_ESTANTERIA)
                        .Select(grp => grp.FirstOrDefault())
                        .ToList();
                }
            }
            catch (Exception e)
            {
                throw new Exception(e.Message);
            }
            return estanterias;
        }

        public List<UBCM> ObtenerUbicacionesPorEstante(string zona, string estanteria, string almacen)
        {
            var ubicaciones = new List<UBCM>();
            try
            {
                using (var context = new SGAContext())
                {
                    context.Configuration.LazyLoadingEnabled = false;
                    //Se desactiva lazyloading para que no haya problemas con la muerte del contexto al llegar al procesamiento en jQuery
                    //Se ordena por altura para poder separar por lados en caso de ordenacion por pasillo
                    ubicaciones = context.UBCM
                        .Where(x => x.sUBCM_ZONA == zona & x.sUBCM_ESTANTERIA == estanteria & x.sUBCM_ALMACEN==almacen)
                        .OrderBy(x=>x.sUBCM_ALTURA)
                        .ThenBy(x=>x.sUBCM_PROFUNDIDAD)
                        .ToList();
                }
            }
            catch (Exception e)
            {
                throw new Exception(e.Message);
            }
            return ubicaciones;
        }

        public UBCM ObtenerOpcionesUbicacion(string almacen, string zona, string estanteria, string profundidad, string altura)
        {
            var ubicacion = new UBCM();
            try
            {
                using (var context = new SGAContext())
                {
                    context.Configuration.LazyLoadingEnabled = false;
                    //Se desactiva lazyloading para que no haya problemas con la muerte del contexto al llegar al procesamiento en jQuery
                    ubicacion = context.UBCM
                        .Where(x => x.sUBCM_ZONA == zona & x.sUBCM_ALMACEN == almacen & x.sUBCM_ESTANTERIA == estanteria & x.sUBCM_PROFUNDIDAD == profundidad && x.sUBCM_ALTURA == altura)
                    .Single();
                }
            }
            catch (Exception e)
            {
                throw new Exception(e.Message);
            }
            return ubicacion;
        }

        public string ObtenerMax(string almacen, string zona)
        {
            var idMax = string.Empty;
            try
            {
                using (var context = new SGAContext())
                {
                    idMax = context.UBCM.
                        Where(x => x.sUBCM_ALMACEN == almacen && x.sUBCM_ZONA == zona)
                    .Max(x => x.sUBCM_ESTANTERIA);
                }
            }
            catch (Exception e)
            {
                throw new Exception(e.Message);
            }
            return idMax;
        }

        public void Guardar()
        {
            try
            {
                using (var context = new SGAContext())
                {
                    if (this.id == 0)
                    {
                        context.Entry(this).State = System.Data.Entity.EntityState.Added;
                    }
                    else
                    {
                        context.Entry(this).State = System.Data.Entity.EntityState.Modified;
                    }

                    context.SaveChanges();
                }
            }
            catch (Exception e)
            {
                throw new Exception(e.Message);
            }
        }
    }
}
