namespace SGA.Models
{
    using System;
    using System.Collections.Generic;
    using System.ComponentModel.DataAnnotations;
    using System.ComponentModel.DataAnnotations.Schema;
    using System.Data.Entity.Spatial;
    using System.Linq;
    using System;
    using System.Security.Cryptography;
    using Microsoft.AspNetCore.Cryptography.KeyDerivation;
    using Insya.Localization.Attributes;
    using Insya.Localization;

    public partial class USRS
    {

        [DatabaseGenerated(DatabaseGeneratedOption.Identity)]
        public int id { get; set; }

        [Key]
        [RequiredLocalized]
        [StringLength(50)]
        public string sUSRS_USUARIO { get; set; }

        [RequiredLocalized]
        [StringLength(256)]
        public string sUSRS_PASSWORD { get; set; }

        public int sUSRS_ROL { get; set; }

        [RequiredLocalized]
        [StringLength(50)]
        public string sUSRS_NOMBRE { get; set; }

        [RequiredLocalized]
        [StringLength(50)]
        public string sUSRS_APELLIDO1 { get; set; }

        [RequiredLocalized]
        [StringLength(50)]
        public string sUSRS_APELLIDO2 { get; set; }

        public bool sUSRS_ACTIVO { get; set; }

        [StringLength(5)]
        public string sUSRS_CULTURA { get; set; }

        [StringLength(128)]
        public string sUSRS_SALT { get; set; }

        public List<USRS> Listar()
        {
            var usuarios = new List<USRS>();
            try
            {
                using (var context = new SGAContext())
                {
                    usuarios = context.USRS.ToList();
                }
            }
            catch (Exception e)
            {
                throw new Exception(e.Message);
            }
            return usuarios;
        }

        public USRS Obtener(string username)
        {
            var usuario = new USRS();
            try
            {
                using (var context = new SGAContext())
                {
                    usuario = context.USRS
                        .Where(x => x.sUSRS_USUARIO == username)
                        .Single();
                }
            }
            catch (Exception e)
            {
                throw new Exception(e.Message);
            }
            return usuario;
        }

        public void Guardar()
        {
            try
            {
                using (var context = new SGAContext())
                {
                    if (this.id == 0)
                    {
                        context.Entry(this).State = System.Data.Entity.EntityState.Added;
                    }
                    else
                    {
                        context.Entry(this).State = System.Data.Entity.EntityState.Modified;
                    }

                    context.SaveChanges();
                }
            }
            catch (Exception e)
            {
                throw new Exception(e.Message);
            }
        }

        public void Eliminar(string username)
        {
            try
            {
                using (var context = new SGAContext())
                {
                    context.Entry(new USRS { sUSRS_USUARIO  = username }).State = System.Data.Entity.EntityState.Deleted;
                    context.SaveChanges();
                }
            }
            catch (Exception e)
            {
                throw new Exception(e.Message);
            }
        }

        //Se utiliza para obtener el salt (codigo q se genera aleatoriamente para codificar la contrasea)
        // y para encriptar la contrasea
        public void SetPasswordHashAndSalt()
        {
           
            // generate a 128-bit salt using a secure PRNG
            byte[] salt = new byte[128 / 8];
            using (var rng = RandomNumberGenerator.Create())
            {
                rng.GetBytes(salt);
            }

            // derive a 256-bit subkey (use HMACSHA1 with 10,000 iterations)
            string hashed = Convert.ToBase64String(KeyDerivation.Pbkdf2(
                password: this.sUSRS_PASSWORD,
                salt: salt,
                prf: KeyDerivationPrf.HMACSHA1,
                iterationCount: 10000,
                numBytesRequested: 256 / 8));

            this.sUSRS_PASSWORD = hashed;
            this.sUSRS_SALT = Convert.ToBase64String(salt);
        }
        
        //Se utiliza para hacer hash de password, y poder conprobar coindidencia con una contrasea almacenada.
        public string HashPassword(string password, string saltorig)
        {
            byte[] salt = Convert.FromBase64String(saltorig);

            string hashed = Convert.ToBase64String(KeyDerivation.Pbkdf2(
                password: password,
                salt: salt,
                prf: KeyDerivationPrf.HMACSHA1,
                iterationCount: 10000,
                numBytesRequested: 256 / 8));
            return hashed;
        }
    }

}
